.. module:: enaml.widgets.toolkit_dialog

============================
enaml.widgets.toolkit_dialog
============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    ToolkitDialog


.. autoclass:: ToolkitDialog
